███████╗ █████╗ ██╗ ██╗██╗ ██╗██████╗ █████╗ ██╗
██╔════╝██╔══██╗██║ ██╔╝██║ ██║██╔══██╗██╔══██╗██║
███████╗███████║█████╔╝ ██║ ██║██████╔╝███████║██║
╚════██║██╔══██║██╔═██╗ ██║ ██║██╔══██╗██╔══██║██║
███████║██║ ██║██║ ██╗╚██████╔╝██║ ██║██║ ██║██║
╚══════╝╚═╝ ╚═╝╚═╝ ╚═╝ ╚═════╝ ╚═╝ ╚═╝╚═╝ ╚═╝╚═╝
Usage
Add to Cargo.toml:
[dependencies]
sakurai = "0.1.1"Testing
Run the test suite:
cargo testRun UB checks:
cargo +nightly miri testSafety & Disclaimers
Sakurai uses a fair bit of unsafe code internally, but the outward APIs are safe Rust.
While this crate is well tested, it’s not recommended for production currently as some APIs are unstable (notably BTree). Use at your own risk.
███████╗ █████╗ ██╗ ██╗██╗ ██╗██████╗ █████╗ ██╗ ██╔════╝██╔══██╗██║ ██╔╝██║ ██║██╔══██╗██╔══██╗██║ ███████╗███████║█████╔╝ ██║ ██║██████╔╝███████║██║ ╚════██║██╔══██║██╔═██╗ ██║ ██║██╔══██╗██╔══██║██║ ███████║██║ ██║██║ ██╗╚██████╔╝██║ ██║██║ ██║██║ ╚══════╝╚═╝ ╚═╝╚═╝ ╚═╝ ╚═════╝ ╚═╝ ╚═╝╚═╝ ╚═╝╚═╝
=====================================================
Re-exports
pub use btree::BTree;pub use fixedvec::FixedVec;pub use hashmap::HashMap;pub use pivot::Pivot;pub use pivot::PivotBuffer;pub use queue::Queue;pub use ring::RingBuffer;pub use stack::Stack;